@@ -1,7 +1,7 @@
 from collections import namedtuple
 from kaa.filetype.default import defaultmode
 from gappedbuf import re as gre
-from kaa.highlight import Tokenizer, Span, Keywords, EndSection
+from kaa.highlight import Tokenizer, Span, Keywords, EndSection, SingleToken
 from kaa.theme import Theme, Style
 
 JavaScriptThemes = {
@@ -11,7 +11,7 @@ JavaScriptThemes = {
         ])
 }
 def build_tokenizer(stop=None, terminates=None):
-    JSTOKENS = namedtuple('jstokens', ['keywords', 'comment1', 'comment2',
+    JSTOKENS = namedtuple('jstokens', ['keywords', 'number', 'comment1', 'comment2',
                        'string1', 'string2', 'stop'])
 
     keywords=Keywords('javasctipt-keyword', 'keyword',
@@ -22,12 +22,14 @@ def build_tokenizer(stop=None, terminates=None):
           "super", "implements", "interface", "let", "package", "private",
           "protected", "public", "static", "yield",])
 
+    number=SingleToken('javascript-numeric', 'number',
+                 [r'\b[0-9]+(\.[0-9]*)*\b', r'\b\.[0-9]+\b'])
     comment1=Span('javascript-comment1', 'comment', r'/\*', r'\*/', escape='\\')
     comment2=Span('javascript-comment2', 'comment', r'//', r'$', escape='\\')
     string1=Span('javascript-string1', 'string', '"', '"', escape='\\')
     string2=Span('javascript-string2', 'string', "'", "'", escape='\\')
 
-    tokens = JSTOKENS(keywords, comment1, comment2, string1, string2, stop)
+    tokens = JSTOKENS(keywords, number, comment1, comment2, string1, string2, stop)
 
     return Tokenizer(tokens, terminates=terminates)
 
