@@ -6,7 +6,27 @@ from kaa.theme import Theme, Style
 DialogThemes = {
     'default':
         Theme([
-            Style('default', 'default', 'default', False, False),
+            Style('default', 'Base3', 'Base02', False, False),
+            Style('title', 'Base3', 'Blue', nowrap=True),
+            Style('caption', 'Menu2', 'Base02', nowrap=True),
+
+            Style('activemark', 'Base02', 'Yellow', nowrap=True),
+            Style('nonactivemark', 'Yellow', 'Base02', nowrap=True),
+
+            Style('button', 'Base3', 'Base01', rjust=True, nowrap=True),
+            Style('button.shortcut', 'Base3', 'Base01', underline=True,
+                    rjust=True, nowrap=True),
+
+            Style('checkbox', 'Base3', 'Base01', rjust=True, nowrap=True),
+            Style('checkbox.checked', 'Menu3', 'Menu2', rjust=True,
+                  nowrap=True),
+            Style('checkbox.shortcut', 'Base3', 'Base01', underline=True,
+                  rjust=True, nowrap=True),
+            Style('checkbox.shortcut.checked', 'Menu3', 'Menu2', 
+                  underline=True, rjust=True, nowrap=True),
+
+            Style('selectitem', 'Cyan', 'Base02', nowrap=True),
+            Style('selectitem-active', 'Base02', 'Yellow', nowrap=True),
     ])
 }
 
