@@ -31,13 +31,6 @@ GrepOption.LASTOPTION = GrepOption()
 GrepThemes = {
     'default':
         Theme([
-            Style('default', 'default', 'Blue'),
-            Style('caption', 'default', 'magenta'),
-            Style('checkbox', 'default', 'magenta', rjust=True, nowrap=True),
-            Style('checkbox.checked', 'yellow', 'red', bold=True, rjust=True,
-                  nowrap=True),
-            Style('checkbox.shortcut', 'green', 'magenta', underline=True,
-                  bold=True, rjust=True, nowrap=True),
         ])
 }
 
@@ -82,7 +75,8 @@ class GrepCommands(editorcommand.EditCommands):
                     wnd.screen.selection.set_range(f, t)
                     
             filterlist.show_listdlg('Recent searches', 
-                kaa.app.config.hist_grepstr.get(), callback)
+                [s for s, info in kaa.app.config.hist_grepstr.get()],
+                callback)
 
         elif dirfrom <= wnd.cursor.pos <= dirto:
             def callback(result):
@@ -94,7 +88,7 @@ class GrepCommands(editorcommand.EditCommands):
                     wnd.screen.selection.set_range(f, t)
        
             hist = []
-            for p in kaa.app.config.hist_grepdir.get():
+            for p, info in kaa.app.config.hist_grepdir.get():
                 path = os.path.relpath(p)
                 hist.append(path if len(path) < len(p) else p)
                 
@@ -111,7 +105,8 @@ class GrepCommands(editorcommand.EditCommands):
                     wnd.screen.selection.set_range(f, t)
                     
             filterlist.show_listdlg('Recent filenames', 
-                kaa.app.config.hist_grepfiles.get(), callback)
+                [s for s, info in kaa.app.config.hist_grepfiles.get()],
+                callback)
 
 
 grepdlg_keys = {
@@ -151,11 +146,11 @@ class GrepDlgMode(dialogmode.DialogMode):
 
             grepdir = config.hist_grepdir.get()
             if grepdir:
-                GrepOption.LASTOPTION.directory = grepdir[0]
+                GrepOption.LASTOPTION.directory = grepdir[0][0]
 
             grepfiles = config.hist_grepfiles.get()
             if grepfiles:
-                GrepOption.LASTOPTION.filenames = grepfiles[0]
+                GrepOption.LASTOPTION.filenames = grepfiles[0][0]
                     
         self.option = GrepOption.LASTOPTION
         
@@ -274,26 +269,26 @@ class GrepDlgMode(dialogmode.DialogMode):
 
     def _get_optionstylename(self, f):
         if f:
-            return 'checkbox.checked'
+            return '.checked'
         else:
-            return 'checkbox'
+            return ''
 
     def update_option_style(self):
         style = self._get_optionstylename(self.option.tree)
-        self._set_option_style('search-tree', style, 'shortcut-t',
-                               'checkbox.shortcut')
+        self._set_option_style('search-tree', 'checkbox'+style, 'shortcut-t',
+                               'checkbox.shortcut'+style)
 
         style = self._get_optionstylename(self.option.ignorecase)
-        self._set_option_style('ignore-case', style, 'shortcut-i',
-                               'checkbox.shortcut')
+        self._set_option_style('ignore-case', 'checkbox'+style, 'shortcut-i',
+                               'checkbox.shortcut'+style)
 
         style = self._get_optionstylename(self.option.word)
-        self._set_option_style('word', style, 'shortcut-w',
-                               'checkbox.shortcut')
+        self._set_option_style('word', 'checkbox'+style, 'shortcut-w',
+                               'checkbox.shortcut'+style)
 
         style = self._get_optionstylename(self.option.regex)
-        self._set_option_style('regex', style, 'shortcut-r',
-                               'checkbox.shortcut')
+        self._set_option_style('regex', 'checkbox'+style, 'shortcut-r',
+                               'checkbox.shortcut'+style)
 
     def _option_updated(self):
         self.update_option_style()
