@@ -12,13 +12,6 @@ from gappedbuf.sre_constants import error as gre_error
 SearchThemes = {
     'default':
         Theme([
-            Style('default', 'default', 'Blue'),
-            Style('caption', 'default', 'magenta'),
-            Style('checkbox', 'default', 'magenta', rjust=True, nowrap=True),
-            Style('checkbox.checked', 'yellow', 'red', bold=True, rjust=True,
-                  nowrap=True),
-            Style('checkbox.shortcut', 'green', 'magenta', underline=True,
-                  bold=True, rjust=True, nowrap=True),
         ])
 }
 
@@ -54,7 +47,8 @@ class SearchCommands(editorcommand.EditCommands):
                 wnd.cursor.setpos(f)
             
         self._show_histdlg(wnd, 'Recent searches', 
-                kaa.app.config.hist_searchstr.get(), callback)
+                [s for s, info in kaa.app.config.hist_searchstr.get()],
+                callback)
         
     @command('searchdlg.toggle.ignorecase')
     @norec
@@ -156,7 +150,7 @@ class SearchDlgMode(dialogmode.DialogMode):
 
     def _build_input(self, f):
         # search text
-        f.append_text('caption', 'Search:')
+        f.append_text('caption', ' Search:')
         f.append_text('default', ' ')
         f.append_text('default', '', mark_pair='searchtext')
         f.append_text('default', ' ')
@@ -164,11 +158,11 @@ class SearchDlgMode(dialogmode.DialogMode):
     def _build_buttons(self, f):
         # buttons
         f.append_text('checkbox', '[&Next]',
-                      shortcut_style='checkbox.shortcut',
+                      shortcut_style='button.shortcut',
                       on_shortcut=self.search_next)
 
         f.append_text('checkbox', '[&Prev]',
-                      shortcut_style='checkbox.shortcut',
+                      shortcut_style='button.shortcut',
                       on_shortcut=self.search_prev)
 
     def _build_options(self, f):
@@ -212,22 +206,22 @@ class SearchDlgMode(dialogmode.DialogMode):
 
     def _get_optionstylename(self, f):
         if f:
-            return 'checkbox.checked'
+            return '.checked'
         else:
-            return 'checkbox'
+            return ''
 
     def update_option_style(self):
         style = self._get_optionstylename(self.option.ignorecase)
-        self._set_option_style('ignore-case', style, 'shortcut-i',
-                               'checkbox.shortcut')
+        self._set_option_style('ignore-case', 'checkbox'+style, 'shortcut-i',
+                               'checkbox.shortcut'+style)
 
         style = self._get_optionstylename(self.option.word)
-        self._set_option_style('word', style, 'shortcut-w',
-                               'checkbox.shortcut')
+        self._set_option_style('word', 'checkbox'+style, 'shortcut-w',
+                               'checkbox.shortcut'+style)
 
         style = self._get_optionstylename(self.option.regex)
-        self._set_option_style('regex', style, 'shortcut-r',
-                               'checkbox.shortcut')
+        self._set_option_style('regex', 'checkbox'+style, 'shortcut-r',
+                               'checkbox.shortcut'+style)
 
     def _option_updated(self):
         self.update_option_style()
@@ -377,7 +371,8 @@ class ReplaceCommands(SearchCommands):
                 wnd.cursor.setpos(f)
                 
         self._show_histdlg(wnd, 'Recent replace strings', 
-                kaa.app.config.hist_replstr.get(), callback)
+                [s for s, info in kaa.app.config.hist_replstr.get()],
+                callback)
 
     @command('replacedlg.history')
     @norec
@@ -439,8 +434,8 @@ class ReplaceDlgMode(SearchDlgMode):
     def _build_buttons(self, f):
         # buttons
         super()._build_buttons(f)
-        f.append_text('checkbox', '[&All]', 'start-all', 'end-all',
-                      shortcut_style='checkbox.shortcut', on_shortcut=self.replace_all)
+        f.append_text('button', '[&All]', 'start-all', 'end-all',
+                      shortcut_style='button.shortcut', on_shortcut=self.replace_all)
 
     def build_document(self):
         f = dialogmode.FormBuilder(self.document)
